<?php
/**
 * Plugin Name: Yourblogjourney Parent Page Child Post Breadcrumbs
 * Plugin URI: https://yourblogjourney.com/parent-page-and-child-post-breadcrumbs
 * Description: A plugin to display breadcrumbs with custom field support, including Parent Page → Child Post, Parent Page → Child Page, and Parent Page → Child Post structures. Fallback to Category → Post if no parent page is set. Includes JSON-LD structured data for SEO.
 * Version: 1.2.5
 * Author: Yourblogjourney.com
 * Author URI: https://yourblogjourney.com
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: yourblogjourney-breadcrumbs
 * Domain Path: /languages
 *
 * @package YourblogjourneyBreadcrumbs
 */

if (!defined('WPINC')) {
    die;
}

define('YOURBLOGJOURNEY_BREADCRUMBS_VERSION', '1.2.5');

// Load Font Awesome
function yourblogjourney_breadcrumbs_load_font_awesome() {
    wp_enqueue_style('font-awesome-home', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/fontawesome.min.css', array(), '5.15.3');
    wp_enqueue_style('font-awesome-home-solid', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/solid.min.css', array(), '5.15.3');
}
add_action('wp_enqueue_scripts', 'yourblogjourney_breadcrumbs_load_font_awesome');

// Handler for ACF Post Object field
function ybj_get_acf_parent_page($post_id) {
    if (!function_exists('get_field')) {
        return false;
    }
    
    $parent_page = get_field('parent_page', $post_id, false);
    
    // Handle array with single value
    if (is_array($parent_page) && !empty($parent_page)) {
        $parent_id = reset($parent_page);
        return is_numeric($parent_id) ? (int) $parent_id : false;
    }
    
    // Fallback for direct ID return
    if (is_numeric($parent_page)) {
        return (int) $parent_page;
    }
    
    return false;
}

function yourblogjourney_breadcrumbs_shorten_title($title, $limit = 30) {
    if (strlen($title) > $limit) {
        return substr($title, 0, $limit) . '...';
    }
    return $title;
}

function yourblogjourney_breadcrumbs_trail_shortcode() {
    if (wp_doing_ajax() || is_front_page()) {
        return '';
    }

    global $post;
    if (!$post || !isset($post->ID)) {
        return '';
    }

    // Initialize JSON-LD data
    $json_breadcrumb = array();
    $position = 1;

    $output = '<nav class="breadcrumb-trail" aria-label="breadcrumb">';
    
    // Home link with Font Awesome icon
    $home_url = home_url();
    $home_text = __('Home', 'yourblogjourney-breadcrumbs');
    $output .= '<a href="' . esc_url($home_url) . '"><i class="fas fa-home" aria-hidden="true"></i> ' . 
               esc_html($home_text) . '</a>';
    
    // Add home to JSON-LD
    $json_breadcrumb[] = array(
        '@type' => 'ListItem',
        'position' => $position++,
        'name' => $home_text,
        'item' => $home_url
    );

    if (is_singular()) {
        $parent_id = ybj_get_acf_parent_page($post->ID);
        
        if ($parent_id && get_post_status($parent_id) === 'publish') {
            // Check for grandparent
            $grandparent_id = ybj_get_acf_parent_page($parent_id);
            if ($grandparent_id && get_post_status($grandparent_id) === 'publish') {
                $grandparent_url = get_permalink($grandparent_id);
                $grandparent_title = get_the_title($grandparent_id);
                $output .= ' » <a href="' . esc_url($grandparent_url) . '">' . 
                          esc_html($grandparent_title) . '</a>';
                
                // Add grandparent to JSON-LD
                $json_breadcrumb[] = array(
                    '@type' => 'ListItem',
                    'position' => $position++,
                    'name' => $grandparent_title,
                    'item' => $grandparent_url
                );
            }

            // Add parent
            $parent_url = get_permalink($parent_id);
            $parent_title = get_the_title($parent_id);
            $output .= ' » <a href="' . esc_url($parent_url) . '">' . 
                      esc_html($parent_title) . '</a>';
            
            // Add parent to JSON-LD
            $json_breadcrumb[] = array(
                '@type' => 'ListItem',
                'position' => $position++,
                'name' => $parent_title,
                'item' => $parent_url
            );
        } elseif (is_single() && !is_page()) {
            // Fallback to category
            $categories = get_the_category();
            if (!empty($categories)) {
                $category = $categories[0];
                $category_url = get_category_link($category->term_id);
                $output .= ' » <a href="' . esc_url($category_url) . '">' . 
                          esc_html($category->name) . '</a>';
                
                // Add category to JSON-LD
                $json_breadcrumb[] = array(
                    '@type' => 'ListItem',
                    'position' => $position++,
                    'name' => $category->name,
                    'item' => $category_url
                );
            }
        }
        
        // Current page
        $current_title = yourblogjourney_breadcrumbs_shorten_title(get_the_title());
        $output .= ' » <span>' . esc_html($current_title) . '</span>';
        
        // Add current page to JSON-LD
        $json_breadcrumb[] = array(
            '@type' => 'ListItem',
            'position' => $position++,
            'name' => $current_title,
            'item' => get_permalink()
        );
    }

    $output .= '</nav>';

    // Add JSON-LD structured data
    $json_ld = array(
        '@context' => 'https://schema.org',
        '@type' => 'BreadcrumbList',
        'itemListElement' => $json_breadcrumb
    );

    $output .= '<script type="application/ld+json">' . 
               wp_json_encode($json_ld, JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT) . 
               '</script>';

    return $output;
}
add_shortcode('yourblogjourney_breadcrumbs', 'yourblogjourney_breadcrumbs_trail_shortcode');

// Enhanced styles
function yourblogjourney_breadcrumbs_styles() {
    ?>
<style type="text/css">
        .breadcrumb-trail {
            margin: 1em 0;
            padding: 0.5em 1em;
            font-size: 0.9em;
            color: #666;
            line-height: 1.4;
        }
        .breadcrumb-trail a {
            color: #0073aa;
            text-decoration: none;
            transition: color 0.2s ease;
        }
        .breadcrumb-trail a:hover {
            color: #00a0d2;
            text-decoration: underline;
        }
        .breadcrumb-trail span {
            color: #333;
            font-weight: 600;
        }
        .breadcrumb-trail i.fas.fa-home {
            margin-right: 5px;
            color: #666;
        }
        @media (max-width: 768px) {
            .breadcrumb-trail {
                font-size: 0.85em;
                margin: 0.5em 0;
                padding: 0.4em 0.8em;
            }
        }
    </style>
    <?php
}
add_action('wp_head', 'yourblogjourney_breadcrumbs_styles');

// Load text domain
function yourblogjourney_breadcrumbs_load_textdomain() {
    load_plugin_textdomain('yourblogjourney-breadcrumbs', false, dirname(plugin_basename(__FILE__)) . '/languages');
}
add_action('plugins_loaded', 'yourblogjourney_breadcrumbs_load_textdomain');